#!/bin/sh

usage()
{
    echo 'Usage: install.sh -s'
    echo '  or:  install.sh -f DEST'
    echo '  or:  install.sh -f EXEC_DEST DOC_DEST SHARE_DEST'
    echo '  or:  install.sh --prefix=DEST [--exec_prefix=] [--docdir=] [--sharedir=]'
    echo '  or:  install.sh exec_prefix=EXEC_DEST docdir=DOC_DEST --sharedir=SHARE_DEST'
    echo
    echo ' or by enviroment variables:'
    echo '  or:  prefix=DEST install.sh'
    echo '  or:  export $prefix=DEST ; install.sh'
    echo
    echo 'Install Opera files to standard or user defined locations.'
    echo
    echo '  -s, --standard               install to standard locations'
    echo '  -f, --force                  install to user defined location(s)'
    echo
    echo '      $prefix'
    echo '      --prefix=                install all files to directory'
    echo
    echo '      $exec_prefix'
    echo '      --exec_prefix=           install Opera binaries to directory'
    echo '      $docdir'
    echo '      --docdir=                install Opera documentation to directory'
    echo '      $sharedir'
    echo '      --sharedir=              install Opera shared files to directory'
    echo
    echo '  -v, --verbose                output which files are copied'
    echo '  -vv                          output info on each executed command'
    echo
    echo '  -V, --version                output version information and exit'
    echo '  -h, --help                   display this help and exit'
    echo
    echo 'If you choose to do a standard locations install, files will be put into'
    echo '/usr/bin, /usr/doc/opera and /usr/share/opera.'
    echo
    echo 'However, if you choose to install to user defined locations, you must either'
    echo '  specify one directory (all files will be put in this directory), or'
    echo '  specify three directories (you may enter the same directory several times).'
}

version()
{
    echo 'install.sh (Opera Software A/S) 1.2'
    echo 'Written by Christian Westgaard <chrisw@opera.com>'
    echo
    echo 'Copyright (C) 2001 Opera Software A/S.'
    echo 'This is free software; There is NO warranty; not even'
    echo 'for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.'
}

error()
{
    case $mesg in

	missing)
	    echo 'install.sh: missing parameter(s)'
	    echo
	    usage
	    ;;

	invalid)
	    echo 'install.sh: invalid parameter(s)'
	    echo
	    usage
	    ;;

	abort)
	    echo 'install.sh: installation aborted by user'
	    ;;

	conflict)
	    echo 'install.sh: conflicting parameters'
	    echo
	    usage
	    ;;
    esac
    exit 1
}

selinsttype()
{
    case $flag_mode in

	--standard)
	    echo 'Running standard installation...'
	    exec_dir="/usr/bin"
	    doc_dir="/usr/doc/opera"
	    share_dir="/usr/share/opera"
	    ;;

	--force)
	    echo 'Running forced installation...'
	    ;;

	--prefix=)
	    echo 'Running prefix installation...'
	    if test $prefix; then 
		exec_dir="$prefix"
		doc_dir="$prefix"
		share_dir="$prefix"
	    fi
	    if test $exec_prefix; then exec_dir="$exec_prefix"; fi
	    if test $docdir; then doc_dir="$docdir"; fi
	    if test $sharedir; then share_dir="$sharedir"; fi
	    ;;
        *) # no install type defined, check envir
	    if test -z "$prefix" && ( test -z "$exec_prefix" || test -z "$docdir" || test -z "$sharedir" )
	      then mesg="missing"; error
	      else flag_mode="--prefix="; selinsttype
	    fi
	    ;;
    esac
}

permitions()
{
    if ! mkdir -p $exec_dir || test ! -w $exec_dir; then echo "You do not have write access to $exec_dir, please change to appropriate user."; exit 1; fi
    if ! mkdir -p $doc_dir || test ! -w $doc_dir; then echo "You do not have write access to $doc_dir, please change to appropriate user."; exit 1; fi
    if ! mkdir -p $share_dir || test ! -w $share_dir; then echo "You do not have write access to $share_dir, please change to appropriate user."; exit 1; fi
}

license()
{
    echo 'The Software License Agreement will now be displayed'
    echo 'Press Q to exit'
    echo 'please wait...'
    sleep 3
    less LICENSE
    echo 'Do you accept [y/n]?'
    read answer
    if test "$answer" != "y" && test "$answer" != "Y"; then mesg="abort"; error; fi
}

runinstall()
{
    # Executable
        chmod $vv 755 opera
	cp $v -fup opera $exec_dir/

    # Documentation
	mkdir $v -p $doc_dir/
	chmod $vv 755 $doc_dir
	cp $v -fup LICENSE $doc_dir

    # Shared files
	mkdir $v -p $share_dir/buttons/
	chmod $vv 755 $share_dir/buttons
	cp $v -Rfup buttons/* $share_dir/buttons/

	# fix for windows button sets
        cd $share_dir/buttons
	if ! test -e Default; then ln -s default Default; fi
	if ! test -e DefSmall; then ln -s defsmall DefSmall; fi
	cd -

	mkdir $v -p $share_dir/help/
	chmod $vv 755 $share_dir/help
	cp $v -Rfup help/* $share_dir/help/
	    
	mkdir $v -p $share_dir/images/
	chmod $vv 755 $share_dir/images
	cp $v -Rfup images/* $share_dir/images/
	
	mkdir $v -p  $share_dir/styles/
	chmod $vv 755 $share_dir/styles
	cp $v -Rfup styles/* $share_dir/styles/

	cp $v -fup opera.xpm opera.wmconfig opera.desktop opera_*.png $share_dir/
	cp $v -iup opera.adr $share_dir/
	

	icons
	gnome
	kde2
	kde

    # Uninstallation
#	echo '' > $share_dir/uninstall.sh
#	echo '#!/bin/sh' >> $share_dir/uninstall.sh
#	echo "exec_dir=$exec_dir" >> $share_dir/uninstall.sh
#	echo "doc_dir=$doc_dir" >> $share_dir/uninstall.sh
#	echo "share_dir=$share_dir" >> $share_dir/uninstall.sh
#	echo "" >> $share_dir/uninstall.sh
#	chmod $vv 755 $share_dir/uninstall.sh

	echo
	echo 'Installation successful. Enjoy !'
	echo "Start with \$PATH/opera, $exec_dir/opera or ./opera"
}

icons()
{
    if test ! -d /usr/share/icons; then install $v -m 755 -o 0 -g 0 -d /usr/share/icons/; fi
    install $v -m 644 -o 0 -g 0 $share_dir/opera.xpm /usr/share/icons/opera.xpm
  
    if test ! -d /usr/share/pixmaps; then install $v -m 755 -o 0 -g 0 -d /usr/share/pixmaps/; fi   
    install $v -m 644 -o 0 -g 0 $share_dir/opera.xpm /usr/share/pixmaps/opera.xpm
  
    if test -d /etc/X11/wmconfig/; then install $v -m 644 -o 0 -g 0 $share_dir/opera.wmconfig /etc/X11/wmconfig/opera; fi
    
    if test -d /etc/X11/applnk/; then
      if test ! -d /etc/X11/applnk/Internet/; then install $v -m 755 -o 0 -g 0 -d /etc/X11/applnk/Internet/; fi
      install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /etc/X11/applnk/Internet/opera.desktop 
    fi
}

gnome()
{
    if test -d /opt/gnome/; then
      if test ! /opt/gnome/share/pixmaps/; then install $v -m 755 -o 0 -g 0 /opt/gnome/share/pixmaps/; fi
      install $v -m 644 -o 0 -g 0 $share_dir/opera.xpm /opt/gnome/share/pixmaps/opera.xpm
      if test -d /opt/gnome/share/gnome/apps/Internet/; then
        install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /opt/gnome/share/gnome/apps/Internet/opera.desktop
      elif test -d /opt/gnome/share/gnome/apps/Networking/WWW/; then
        install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /opt/gnome/share/gnome/apps/Networking/WWW/opera.desktop
      else
        install $v -m 755 -o 0 -g 0 /opt/gnome/share/gnome/apps/Internet/
        install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /opt/gnome/share/gnome/apps/Internet/opera.desktop
      fi
    else
      if test -d /usr/share/gnome/apps/; then
        if test -d /usr/share/gnome/apps/Internet/; then
          install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /usr/share/gnome/apps/Internet/opera.desktop
        elif test -d /usr/share/gnome/apps/Networking/WWW; then
          install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /usr/share/gnome/apps/Networking/WWW/opera.desktop
        else
          install $v -m 755 -o 0 -g 0 /usr/share/gnome/apps/Internet/
          install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /usr/share/gnome/apps/Internet/opera.desktop
        fi
      fi   
    fi
}

kde2()
{
    if test -d /opt/kde2/; then
      DIR_HI=/opt/kde2/share/icons/hicolor
      DIR_LO=/opt/kde2/share/icons/locolor
      if test ! -d $DIR_HI/48x48/apps/; then install $v -m 755 -o 0 -g 0 -d $DIR_HI/48x48/apps/; fi
      if test ! -d $DIR_HI/32x32/apps/; then install $v -m 755 -o 0 -g 0 -d $DIR_HI/32x32/apps/; fi
      if test ! -d $DIR_HI/22x22/apps/; then install $v -m 755 -o 0 -g 0 -d $DIR_HI/22x22/apps/; fi
      if test ! -d $DIR_LO/32x32/apps/; then install $v -m 755 -o 0 -g 0 -d $DIR_LO/32x32/apps/; fi
      if test ! -d $DIR_LO/22x22/apps/; then install $v -m 755 -o 0 -g 0 -d $DIR_LO/22x22/apps/; fi
      if test ! -d $DIR_LO/16x16/apps/; then install $v -m 755 -o 0 -g 0 -d $DIR_LO/16x16/apps/; fi
      install $v -m 644 -o 0 -g 0 $share_dir/opera_48x48.png $DIR_HI/48x48/apps/opera.png
      install $v -m 644 -o 0 -g 0 $share_dir/opera_32x32.png $DIR_HI/32x32/apps/opera.png
      install $v -m 644 -o 0 -g 0 $share_dir/opera_22x22.png $DIR_HI/22x22/apps/opera.png
      install $v -m 644 -o 0 -g 0 $share_dir/opera_32x32.png $DIR_LO/32x32/apps/opera.png
      install $v -m 644 -o 0 -g 0 $share_dir/opera_22x22.png $DIR_LO/22x22/apps/opera.png
      install $v -m 644 -o 0 -g 0 $share_dir/opera_16x16.png $DIR_LO/16x16/apps/opera.png
      if test ! -d /opt/kde2/share/applnk/Internet/; then install $v -m 755 -o 0 -g 0 -d /opt/kde2/share/applnk/Internet/; fi
      install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /opt/kde2/share/applnk/Internet/opera.desktop
    else
      if test -d /usr/share/applnk/Networking; then
        if test ! -d /usr/share/applnk/Networking/WWW/; then install $v -m 755 -o 0 -g 0 -d /usr/share/applnk/Networking/WWW/; fi
        install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /usr/share/applnk/Networking/WWW/opera.desktop
      fi
    fi
}

kde()
{
    if test -d /opt/kde/; then
      if test ! -d /opt/kde/share/icons/; then install $v -m 755 -o 0 -g 0 -d /opt/kde/share/icons/; fi
      if test ! -d /opt/kde/share/applnk/Internet/; then install $v -m 755 -o 0 -g 0 -d /opt/kde/share/applnk/Internet/; fi
      install $v -m 644 -o 0 -g 0 $share_dir/opera.xpm /opt/kde/share/icons/opera.xpm
      install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /opt/kde/share/applnk/Internet/opera.desktop
    else
      if test -d /usr/share/applnk/Internet/; then install $v -m 644 -o 0 -g 0 $share_dir/opera.desktop /usr/share/applnk/Internet/opera.desktop; fi    
    fi
}

# Execution start point (parameter loop)

v=""
vv=""
flag_mode=""

prefix=`printenv prefix`
exec_prefix=`printenv exec_prefix`
docdir=`printenv docdir`
sharedir=`printenv sharedir`

if test "$#" = 0 && test -z "$prefix" && ( test -z "$exec_prefix" || test -z "$docdir" || test -z "$sharedir" ) then mesg="missing"; error ; fi

while test "$1" ; do
case $1 in

    -h|--help) usage; exit 0 ;;

    -V|--version) version; exit 0 ;;

    -v|--verbose)
	v='--verbose'
	shift
	;;

    -vv)
	v='--verbose'
	vv='--verbose'
	shift
	;;

    -s|--standard)
	if test -z "$flag_mode" ; then 
	    flag_mode="--standard"
	    shift
	  else
	  mesg="conflict"; error
	fi
	;;

    -f|--force)
	if test -z "$flag_mode" ; then  
	    flag_mode="--force"
	    shift
	    if test "$1" = ""; then mesg="missing"; error
	      elif test "$2" = ""; then
		echo "Only one destination parameter found, all files will be installed to $1"
		echo 'Do you want to continue [y/n]?'
		read answer
		if test "$answer" != "y" && test "$answer" != "Y"
		then
		    mesg="abort"; error
		else
		    exec_dir="$1"
		    doc_dir="$1"
		    share_dir="$1"
		    shift
		fi
	      elif test "$3" = ""; then mesg="missing"; error
	      else
		exec_dir="$1"
		doc_dir="$2"
		share_dir="$3"
		shift 3
	    fi
	  else
	  mesg="conflict" ; error
	fi
	;;
	

    --prefix=*)
	if test "$flag_mode" = "--prefix=" ||  test -z "$flag_mode" ; then
	    flag_mode="--prefix="

	    param=`echo "$1" | sed -e 's/--prefix=//'`
	    if test $param; then prefix=$param; fi
	    shift
	  else
	  mesg="conflict" ; error
	fi
	;;

    --exec_prefix=*)
	if test "$flag_mode" = "--prefix=" || test -z "$flag_mode" ; then
	    flag_mode="--prefix="

	    param=`echo "$1" | sed -e 's/--exec_prefix=//'`
	    if test $param; then exec_prefix=$param; fi
	    shift
	  else
	  mesg="conflict" ; error
	fi
	;;

    --docdir=*)
	if test "$flag_mode" = "--prefix=" || test -z "$flag_mode" ; then
	    flag_mode="--prefix="

	    param=`echo "$1" | sed -e 's/--docdir=//'`
	    if test $param; then docdir=$param; fi
	    shift
	  else
	  mesg="conflict" ; error
	fi
	;;

    --sharedir=*)
	if test "$flag_mode" = "--prefix=" || test -z "$flag_mode" ; then
	    flag_mode="--prefix="

	    param=`echo "$1" | sed -e 's/--sharedir=//'`
	    if test $param; then sharedir=$param; fi
	    shift
	  else
	  mesg="conflict" ; error
	fi
	;;

     *) mesg="invalid"; error ;;
esac
done # Parameter loop

    selinsttype
    permitions
    license
    runinstall
exit 0




